@@ -1,5 +1,5 @@
 name = 'SwSpotify'
-__version__ = '1.1.2'
+__version__ = '1.2.1'
 
 
 class WebData:
@@ -9,9 +9,14 @@ class WebData:
 
     @staticmethod
     def set_song(data):
-        WebData.track = data['title']
-        WebData.artist = data['artist']
-        WebData.playState = data['playState']
+        try:
+            WebData.track = data['title']
+            WebData.artist = data['artist']
+            WebData.playState = data['playState']
+        except KeyError:
+            WebData.track = None
+            WebData.artist = None
+            WebData.playState = None
 
 
 class SpotifyNotRunning(Exception):
